pub struct Checkpointer { /* private fields */ }Expand description
Struct responsible of fetching the output for a node in the autodiff graph during a backward pass
Implementations
Sourceimpl Checkpointer
impl Checkpointer
Sourcepub fn new(
backward_states: BackwardStates,
retro_forwards: RetroForwards,
node_tree: NodeTree,
) -> Self
pub fn new( backward_states: BackwardStates, retro_forwards: RetroForwards, node_tree: NodeTree, ) -> Self
Constructs a new Checkpointer.
Sourceimpl Checkpointer
impl Checkpointer
Sourcepub fn retrieve_node_output<T>(&mut self, node_id: NodeId) -> T
pub fn retrieve_node_output<T>(&mut self, node_id: NodeId) -> T
Gives the output of the given node, by recursively asking parents to compute themselves or give their pre-computed tensors.